@@ -8,6 +8,7 @@ def get_server_url(server_root, username, password):
     else:
         return "http://%(server)s" % {"server": server_root }
 
+
 def get_dynamic_db_settings(server_root, username, password, dbname, installed_apps):
     """
     Get dynamic database settings.  Other apps can use this if they want to change
@@ -16,10 +17,10 @@ def get_dynamic_db_settings(server_root, username, password, dbname, installed_a
 
     server = get_server_url(server_root, username, password)
     database = "%(server)s/%(database)s" % {"server": server, "database": dbname}
-    posturl = "http://%s/%s/_design/couchforms/_update/xform/" % (server_root, dbname)
-    return {"COUCH_SERVER":  server,
-            "COUCH_DATABASE": database,
-            "XFORMS_POST_URL": posturl }
+    return {
+        "COUCH_SERVER":  server,
+        "COUCH_DATABASE": database,
+    }
 
 
 def get_commit_id():
